# Slot: repr


the python representation of this type if different than the base type

URI: [http://w3id.org/biolink/biolinkml/meta/repr](slot_uri)
## Domain and Range

[TypeDefinition](TypeDefinition.md) -><sub>opt</sub> [String](String.md)
## Inheritance

## Children

## Used by

 * [TypeDefinition](TypeDefinition.md)
